from enum import Enum


# ISO 639-1
class LanguageEnum(str, Enum):
    en = "en"
    zh = "zh"
    fr = "fr"
    de = "de"
    es = "es"
    ja = "ja"
    ru = "ru"
    ko = "ko"
    it = "it"
    pt = "pt"
